@@ -33,6 +33,9 @@
 #include "bakery/View/View.h"
 #include <bakery/Utilities/BusyCursor.h>
 
+namespace Glom
+{
+
 class LayoutItem_GroupBy;
 class LayoutItem_Summary;
 class LayoutItem_VerticalGroup;
@@ -86,13 +89,9 @@ public:
   static type_vecFields get_fields_for_table_from_database(const Glib::ustring& table_name, bool including_system_fields = false);
   static bool get_field_exists_in_database(const Glib::ustring& table_name, const Glib::ustring& field_name);
 
-  /** Create an appropriate title for an ID string.
-   * For instance, date_of_birth would become Date Of Birth.
-   */
-  static Glib::ustring util_title_from_string(const Glib::ustring& text);
 
   //This is const because const means not changing this instance, not whether we change the database.
-  virtual Glib::RefPtr<Gnome::Gda::DataModel> query_execute(const Glib::ustring& strQuery, Gtk::Window* parent_window = 0) const;
+  static Glib::RefPtr<Gnome::Gda::DataModel> query_execute(const Glib::ustring& strQuery, Gtk::Window* parent_window = 0);
 
   bool add_standard_groups();
   bool add_standard_tables() const;
@@ -276,36 +275,9 @@ protected:
   Gnome::Gda::Value get_field_value_in_database(const LayoutFieldInRecord& field_in_record, Gtk::Window* parent_window);
 
 
-  type_vecStrings get_database_groups() const;
-  type_vecStrings get_database_users(const Glib::ustring& group_name = Glib::ustring()) const;
-  Privileges get_table_privileges(const Glib::ustring& group_name, const Glib::ustring& table_name) const;
-  void set_table_privileges(const Glib::ustring& group_name, const Glib::ustring& table_name, const Privileges& privs, bool developer_privs = false);
-  Glib::ustring get_user_visible_group_name(const Glib::ustring& group_name) const;
-
-  type_vecStrings get_groups_of_user(const Glib::ustring& user) const;
-  bool get_user_is_in_group(const Glib::ustring& user, const Glib::ustring& group) const;
-  Privileges get_current_privs(const Glib::ustring& table_name) const;
-
   SystemPrefs get_database_preferences() const;
   void set_database_preferences(const SystemPrefs& prefs);
 
-  void report_build(const FoundSet& found_set, const sharedptr<const Report>& report, Gtk::Window* parent_window = 0);
-
-  void report_build_groupby(const FoundSet& found_set_parent, xmlpp::Element& parent_node, const sharedptr<LayoutItem_GroupBy>& group_by);
-  void report_build_groupby_children(const FoundSet& found_set, xmlpp::Element& nodeGroupBy, const sharedptr<LayoutItem_GroupBy>& group_by);
-  void report_build_summary(const FoundSet& found_set_parent, xmlpp::Element& parent_node, const sharedptr<LayoutItem_Summary>& summary);
-  void report_build_headerfooter(const FoundSet& found_set, xmlpp::Element& parent_node, const sharedptr<LayoutGroup>& group);
-
-  typedef std::vector< sharedptr<LayoutItem> > type_vecLayoutItems;
-
-  void report_build_records(const FoundSet& found_set, xmlpp::Element& parent_node, const type_vecLayoutItems& items, bool one_record_only = false);
-  void report_build_records_get_fields(const FoundSet& found_set, const sharedptr<LayoutGroup>& group, type_vecLayoutFields& items);
-  void report_build_records_field(const FoundSet& found_set, xmlpp::Element& nodeParent, const sharedptr<const LayoutItem_Field>& field, const Glib::RefPtr<Gnome::Gda::DataModel>& datamodel, guint row, guint& colField, bool vertical = false);
-  void report_build_records_text(const FoundSet& found_set, xmlpp::Element& nodeParent, const sharedptr<const LayoutItem_Text>& textobject, bool vertical = false);
-  void report_build_records_image(const FoundSet& found_set, xmlpp::Element& nodeParent, const sharedptr<const LayoutItem_Image>& imageobject, bool vertical = false);
-  void report_build_records_vertical_group(const FoundSet& found_set, xmlpp::Element& vertical_group_node, const sharedptr<LayoutItem_VerticalGroup>& group, const Glib::RefPtr<Gnome::Gda::DataModel>& datamodel, guint row, guint& field_index);
-
-
   Gnome::Gda::Value auto_increment_insert_first_if_necessary(const Glib::ustring& table_name, const Glib::ustring& field_name) const;
 
   /** Get the next auto-increment value for this primary key, from the glom system table.
@@ -335,35 +307,18 @@ protected:
   static bool get_field_primary_key_index_for_fields(const type_vecFields& fields, guint& field_column);
   static bool get_field_primary_key_index_for_fields(const type_vecLayoutFields& fields, guint& field_column);
 
-  static Glib::ustring util_string_from_decimal(guint decimal);
-  static guint util_decimal_from_string(const Glib::ustring& str);
 
-  static bool util_string_has_whitespace(const Glib::ustring& text);
 
   static type_vecStrings util_vecStrings_from_Fields(const type_vecFields& fields);
 
-  //Utlility functions to help with the odd formats of postgres internal catalog fields:
-  static Glib::ustring string_trim(const Glib::ustring& str, const Glib::ustring& to_remove);
-  static type_vecStrings string_separate(const Glib::ustring& str, const Glib::ustring& separator);
-  static type_vecStrings pg_list_separate(const Glib::ustring& str);
+  bool get_primary_key_is_in_foundset(const FoundSet& found_set, const Gnome::Gda::Value& primary_key_value);
 
-  /** @param not_extras If this is true, then do not set extra details, such as NOT NULL. You should do that later, when you are ready.
-   */
-  bool postgres_add_column(const Glib::ustring& table_name, const sharedptr<const Field>& field, bool not_extras = false) const;
-
-  /**
-   * @param table_name The name of the table that will be affected.
-   * @param field_old The definition of the field that will be changed.
-   * @param field The new definition to give the field.
-   * @param set_anyway If this is true, then set the extra details even if @field_old has the same properties.
-   * @result The new field definition, with any necessary changes.
-   */
-  sharedptr<Field> postgres_change_column_extras(const Glib::ustring& table_name, const sharedptr<const Field>& field_old, const sharedptr<const Field>& field, bool set_anyway = false) const;
-
-  void handle_error(const std::exception& ex) const; //TODO_port: This is probably useless now.
-  bool handle_error() const;
+  static void handle_error(const std::exception& ex); //TODO_port: This is probably useless now.
+  static bool handle_error();
 
   type_field_calcs m_FieldsCalculationInProgress; //Prevent circular calculations and recalculations.
 };
 
+} //namespace Glom
+
 #endif //BASE_DB_H
