@@ -25,12 +25,15 @@
 #include "imageglom.h"
 #include "labelglom.h"
 #include <gtkmm/checkbutton.h>
-#include "../data_structure/glomconversions.h"
+#include <glom/libglom/data_structure/glomconversions.h>
 #include "../mode_data/box_data_list_related.h"
 #include "../mode_data/dialog_choose_relationship.h"
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
 #include <glibmm/i18n.h>
 
+namespace Glom
+{
+
 FlowTableWithFields::Info::Info()
 : m_first(0),
   m_second(0),
@@ -271,7 +274,8 @@ void FlowTableWithFields::add_layout_notebook_at_position(const sharedptr<Layout
       if(portal)
       {
         const Glib::ustring tab_title = glom_get_sharedptr_title_or_name(portal->get_relationship());
-        tab_label->set_markup(Bakery::App_Gtk::util_bold_message(tab_title));
+        //tab_label->set_markup(Bakery::App_Gtk::util_bold_message(tab_title));
+        tab_label->set_label(tab_title);
 
         //Add a Related Records list for this portal:
         Box_Data_List_Related* portal_box = create_related(portal, false /* no label, because it's in the tab instead. */);
@@ -279,12 +283,13 @@ void FlowTableWithFields::add_layout_notebook_at_position(const sharedptr<Layout
         portal_box->show();
         notebook_widget->append_page(*portal_box, *tab_label);
 
-        //add_layoutwidgetbase(portal_box, add_before);
+        add_layoutwidgetbase(portal_box, add_before);
       }
       else
       {
         const Glib::ustring tab_title = group->get_title_or_name();
-        tab_label->set_markup(Bakery::App_Gtk::util_bold_message(tab_title));
+        //tab_label->set_markup(Bakery::App_Gtk::util_bold_message(tab_title));
+        tab_label->set_label(tab_title);
 
         //Add a FlowTable for this group:
         FlowTableWithFields* flow_table = Gtk::manage( new FlowTableWithFields() );
@@ -408,19 +413,16 @@ void FlowTableWithFields::add_field_at_position(const sharedptr<LayoutItem_Field
   info.m_second = pDataWidget; 
   info.m_second->show_all();
 
-  info.m_first = Gtk::manage(new Gtk::Alignment());
-
   //Add a label, if one is necessary:
   Gtk::Label* label = info.m_second->get_label();
+  info.m_first = label;
   if(label && !label->get_text().empty())
   {
-    info.m_first->add( *label );
-    label->set_alignment(Gtk::ALIGN_RIGHT, Gtk::ALIGN_CENTER); //Align right.
+    label->property_xalign() = 0.0f; //Equivalent to Gtk::ALIGN_LEFT, but we can't use that here.
+    label->property_yalign() = 0.5f; //Equivalent ot Gtk::ALIGN_CENTER, but we can't use that here.; 
     label->show();
 
-    info.m_first->show();
-    info.m_first->set(Gtk::ALIGN_RIGHT, Gtk::ALIGN_CENTER);
-    info.m_first->show_all_children(); //This does not seem to work, so we show the label explicitly.
+    label->show();
   }
 
   //info.m_group = layoutitem_field.m_group;
@@ -428,7 +430,16 @@ void FlowTableWithFields::add_field_at_position(const sharedptr<LayoutItem_Field
   //Expand multiline text fields to take up the maximum possible width:
   bool expand_second = false;
   if( (layoutitem_field->get_glom_type() == Field::TYPE_TEXT) && layoutitem_field->get_formatting_used().get_text_format_multiline())
+  {
     expand_second = true;
+    if(label)
+      label->property_yalign() = 0.0f; //Equivalent to Gtk::ALIGN_TOP. Center is neater next to entries, but center is silly next to multi-line text boxes.
+  }
+  else if(layoutitem_field->get_glom_type() == Field::TYPE_IMAGE)
+  {
+    if(label)
+      label->property_yalign() = 0.0f; //Equivalent to Gtk::ALIGN_TOP. Center is neater next to entries, but center is silly next to large images.
+  }
 
   add(*(info.m_first), *(info.m_second), expand_second);
 
@@ -442,7 +453,7 @@ void FlowTableWithFields::add_field_at_position(const sharedptr<LayoutItem_Field
 }
 
 
-void FlowTableWithFields::add_button_at_position(const sharedptr<LayoutItem_Button>& layoutitem_button, const Glib::ustring& table_name, const type_list_layoutwidgets::iterator& add_before)
+void FlowTableWithFields::add_button_at_position(const sharedptr<LayoutItem_Button>& layoutitem_button, const Glib::ustring& /* table_name */, const type_list_layoutwidgets::iterator& add_before)
 {
   //Add the widget:
   ButtonGlom* button = Gtk::manage(new ButtonGlom());
@@ -461,7 +472,7 @@ void FlowTableWithFields::add_button_at_position(const sharedptr<LayoutItem_Butt
   add(*button);
 }
 
-void FlowTableWithFields::add_textobject_at_position(const sharedptr<LayoutItem_Text>& layoutitem_text, const Glib::ustring& table_name, const type_list_layoutwidgets::iterator& add_before)
+void FlowTableWithFields::add_textobject_at_position(const sharedptr<LayoutItem_Text>& layoutitem_text, const Glib::ustring& /* table_name */, const type_list_layoutwidgets::iterator& add_before)
 {
   //Add the widget:
   Gtk::Alignment* alignment_label = Gtk::manage(new Gtk::Alignment());
@@ -492,7 +503,7 @@ void FlowTableWithFields::add_textobject_at_position(const sharedptr<LayoutItem_
   }
 }
 
-void FlowTableWithFields::add_imageobject_at_position(const sharedptr<LayoutItem_Image>& layoutitem_image, const Glib::ustring& table_name, const type_list_layoutwidgets::iterator& add_before)
+void FlowTableWithFields::add_imageobject_at_position(const sharedptr<LayoutItem_Image>& layoutitem_image, const Glib::ustring& /* table_name */, const type_list_layoutwidgets::iterator& add_before)
 {
   //Add the widget:
   ImageGlom* image = Gtk::manage(new ImageGlom());
@@ -822,76 +833,6 @@ void FlowTableWithFields::set_design_mode(bool value)
   }
 }
 
-/*
-void FlowTableWithFields::get_layout_groups(Document_Glom::type_mapLayoutGroupSequence& groups)
-{
-  //This is only called on the top-level FlowTable.
-  //It assumes that there are only groups in this FlowTable,
-  //and no other layout items:
-  Document_Glom::type_mapLayoutGroupSequence::size_type sequence = 1; //0 means no position.
-  for(type_list_layoutwidgets::iterator iter = m_list_layoutwidgets.begin(); iter != m_list_layoutwidgets.end(); ++iter)
-  {
-    LayoutWidgetBase* pLayoutWidget = *iter;
-    if(pLayoutWidget)
-    {
-      FlowTableWithFields* pFlowTable = dynamic_cast<FlowTableWithFields*>(pLayoutWidget);
-      if(pFlowTable)
-      {
-        //recurse:
-        sharedptr<LayoutGroup> group_child = pFlowTable->get_layout_group();
-        groups[sequence] = group_child;
-
-        ++sequence;
-      }
-    }
-  }
-
-}
-*/
-
-/*
-sharedptr<LayoutGroup> FlowTableWithFields::get_layout_group()
-{
-  sharedptr<LayoutGroup> group;
-
-  //Initialize output parameter:
-  //group = LayoutGroup();
-  sharedptr<const LayoutGroup> pGroupExisting = sharedptr<const LayoutGroup>::cast_dynamic(get_layout_item());
-  if(pGroupExisting)
-  {
-    //Start with the same information:
-    group = glom_sharedptr_clone(pGroupExisting); //TODO_Performance: Copy without copying/clone the children.
-    group->remove_all_items(); //We will readd these.
-  }
-
-  //Iterate over the data widgets:
-  for(type_list_layoutwidgets::iterator iter = m_list_layoutwidgets.begin(); iter != m_list_layoutwidgets.end(); ++iter)
-  {
-    LayoutWidgetBase* pLayoutWidget = *iter;
-    if(pLayoutWidget)
-    {
-      FlowTableWithFields* pFlowTable = dynamic_cast<FlowTableWithFields*>(pLayoutWidget);
-      if(pFlowTable)
-      {
-        //recurse:
-        sharedptr<LayoutGroup> group_child = pFlowTable->get_layout_group();
-        group->add_item(group_child);
-      }
-      else
-      {
-        sharedptr<const LayoutItem> pLayoutItem = (*iter)->get_layout_item();
-        if(pLayoutItem)
-        {
-          group->add_item(pLayoutItem);
-        }
-
-      }
-    }
-  }
-
-  return group;
-}
-*/
 
 void FlowTableWithFields::add_layoutwidgetbase(LayoutWidgetBase* layout_widget)
 {
@@ -908,45 +849,70 @@ void FlowTableWithFields::add_layoutwidgetbase(LayoutWidgetBase* layout_widget,
 
 void FlowTableWithFields::on_layoutwidget_changed()
 {
-  /*
-  sharedptr<LayoutGroup> pLayoutItem = sharedptr<LayoutGroup>::cast_dynamic(get_layout_item());
-  if(pLayoutItem)
-  {
-    //Update tha LayoutItem by looking at the child widgets:
-    sharedptr<LayoutGroup> group = get_layout_group();
-    set_layout_item(group, m_table_name);
-  }
-  */
-
   //Forward the signal to the container:
   signal_layout_changed().emit();
 }
 
 void FlowTableWithFields::on_datawidget_layout_item_added(LayoutWidgetBase::enumType item_type, DataWidget* pDataWidget)
 {
-  //Get the position of the selected item:
-  type_list_layoutwidgets::iterator iterAfter = m_list_layoutwidgets.end();
-  type_list_layoutwidgets::iterator iterFind = std::find(m_list_layoutwidgets.begin(), m_list_layoutwidgets.end(), pDataWidget);
-  if(iterFind != m_list_layoutwidgets.end())
+  //Get the widget's layout item:
+  sharedptr<const LayoutItem> layout_item = pDataWidget->get_layout_item();
+  if(!layout_item)
   {
-    iterAfter = iterFind;
-    ++iterAfter; //std::list<>::insert() inserts before, but we want to insert after, so we increment..
+    std::cerr << "FlowTableWithFields::on_datawidget_layout_item_added(): layout_item is null." << std::endl;
+    return;
   }
 
+  //std::cout << "debug: layout_item name=" << layout_item->get_name() << std::endl;
+
+
+  //Get the group that the widget's layout item is in:
+  sharedptr<LayoutGroup> layout_group = sharedptr<LayoutGroup>::cast_dynamic(get_layout_item());
+  if(!layout_group)
+  {
+    std::cerr << "FlowTableWithFields::on_datawidget_layout_item_added(): layout_group is null." << std::endl;
+    return;
+  }
+
+  //Get the position of the selected item in its group:
+  int position = -1;
+  LayoutGroup::type_map_items& map_items = layout_group->m_map_items;
+  for(LayoutGroup::type_map_items::const_iterator iter = map_items.begin(); iter != map_items.end(); ++iter)
+  {
+    sharedptr<const LayoutItem> item = iter->second;
+    if(item && (item.obj() == layout_item.obj()))
+    {
+      position = iter->first;
+ 
+      //std::cout << "debug: position found = " << position << ", name=" << iter->second->get_name() << std::endl;
+
+      break;
+    }
+  }
+
+  if(position == -1)
+  {
+    std::cerr << "FlowTableWithFields::on_datawidget_layout_item_added(): can't find layout_item in layout_group." << std::endl;
+    return;
+  }
+
+  
+  //Create/Choose the new layout item:
+  sharedptr<LayoutItem> layout_item_new;
   if(item_type == LayoutWidgetBase::TYPE_FIELD)
   {
     sharedptr<LayoutItem_Field> layout_item_field = pDataWidget->offer_field_list(m_table_name);
     if(layout_item_field)
     {
       //TODO: privileges.
-      add_layout_item_at_position(layout_item_field, iterAfter);
+      layout_item_new = layout_item_field; 
     }
   }
   else if(item_type == LayoutWidgetBase::TYPE_GROUP)
   {
     sharedptr<LayoutGroup> layout_item = sharedptr<LayoutGroup>::create();
     layout_item->set_title(_("New Group"));
-    add_layout_item_at_position(layout_item, iterAfter);
+    layout_item_new = layout_item;
   }
   else if(item_type == LayoutWidgetBase::TYPE_NOTEBOOK)
   {
@@ -959,7 +925,7 @@ void FlowTableWithFields::on_datawidget_layout_item_added(LayoutWidgetBase::enum
     group_tab->set_title(_("Tab One"));
     layout_item->add_item(group_tab);
 
-    add_layout_item_at_position(layout_item, iterAfter);
+    layout_item_new = layout_item;
   }
   else if(item_type == LayoutWidgetBase::TYPE_PORTAL)
   {
@@ -985,7 +951,7 @@ void FlowTableWithFields::on_datawidget_layout_item_added(LayoutWidgetBase::enum
           {
             sharedptr<LayoutItem_Portal> layout_item = sharedptr<LayoutItem_Portal>::create();
             layout_item->set_relationship(relationship);
-            add_layout_item_at_position(layout_item, iterAfter);
+            layout_item_new = layout_item;
           }
         }
 
@@ -1002,18 +968,48 @@ void FlowTableWithFields::on_datawidget_layout_item_added(LayoutWidgetBase::enum
     sharedptr<LayoutItem_Button> layout_item = sharedptr<LayoutItem_Button>::create();
     layout_item->set_name(_("button"));
     layout_item->set_title(_("New Button"));
-    add_layout_item_at_position(layout_item, iterAfter);
+    layout_item_new = layout_item;
   }
   else if(item_type == LayoutWidgetBase::TYPE_BUTTON)
   {
     sharedptr<LayoutItem_Text> layout_item = sharedptr<LayoutItem_Text>::create();
     layout_item->set_name(_("text"));
     layout_item->set_text(_("New Text"));
-    add_layout_item_at_position(layout_item, iterAfter);
+    layout_item_new = layout_item;
   }
 
-  //TODO: Only if it has really changed:
-  signal_layout_changed().emit(); //This should result in a complete re-layout.
+
+  if(layout_item_new)
+  {
+    //Move the subsequent items forwards:
+    LayoutGroup::type_map_items::iterator iterPos = map_items.find(position);
+    if(iterPos == map_items.end())
+    {
+      std::cerr << "FlowTableWithFields::on_datawidget_layout_item_added(): Can not find iter for layout_item in layout_group with found position." << std::endl;
+      return;
+    }
+
+    LayoutGroup::type_map_items::iterator iterBeforeEnd = map_items.end();
+    --iterBeforeEnd;
+    for(LayoutGroup::type_map_items::iterator iter = iterBeforeEnd; iter != iterPos; --iter)
+    {
+      const int position_next = iter->first + 1;
+      iter->second->m_sequence = position_next;
+      map_items[position_next] = iter->second;  
+      iter->second = sharedptr<LayoutItem>();
+    }
+
+    //This position is now free for us to insert something:
+    const int position_new = position + 1;
+    //std::cout << "debug: position_new=" << position_new << std::endl;  
+
+    layout_item_new->m_sequence = position_new;
+    map_items[position_new] = layout_item_new;
+  
+    //We have changed the structure itself in the document, because we are using the same structure via sharedptr.
+    //So we just tell the parent widgets to rebuild the layout from the document:
+    signal_layout_changed().emit(); //This should result in a complete re-layout.
+  }
 }
 
 void FlowTableWithFields::on_portal_record_changed(const Glib::ustring& relationship_name)
@@ -1058,3 +1054,4 @@ void FlowTableWithFields::on_flowtable_requested_related_details(const Glib::ust
   signal_requested_related_details().emit(table_name, primary_key_value);
 }
 
+} //namespace Glom
